@@ -599,7 +599,13 @@ def diffeqsolve(
 
     # Error checking
     if dt0 is not None:
-        error_if(lambda: (t1 - t0) * dt0 <= 0, "Must have (t1 - t0) * dt0 > 0")
+        msg = (
+            "Must have (t1 - t0) * dt0 > 0, we instead got: "
+            f"t1, with value: {t1} and type {type(t1)}, "
+            f"t0, with value: {t0} and type {type(t0)} and, "
+            f"dt0, with value: {dt0} and type {type(dt0)}"
+        )
+        error_if(lambda: (t1 - t0) * dt0 <= 0, msg)
 
     # Error checking
     term_leaves, term_structure = jax.tree_flatten(
@@ -622,8 +628,8 @@ def diffeqsolve(
     if is_sde(terms):
         if not isinstance(solver, (AbstractItoSolver, AbstractStratonovichSolver)):
             warnings.warn(
-                f"`{solver.__name__}` is not marked as converging to either the Itô "
-                "or the Stratonovich solution."
+                f"`{type(solver).__name__}` is not marked as converging to either the "
+                "Itô or the Stratonovich solution."
             )
         if isinstance(adjoint, BacksolveAdjoint):
             if isinstance(solver, AbstractItoSolver):
