@@ -1,7 +1,6 @@
 from typing import Tuple
 
 import jax
-import jax.flatten_util as fu
 
 from ..custom_types import Bool, DenseInfo, PyTree, Scalar
 from ..local_interpolation import LocalLinearInterpolation
@@ -17,10 +16,7 @@ _SolverState = None
 
 def _implicit_relation(z1, nonlinear_solve_args):
     vf_prod, t1, y0, args, control = nonlinear_solve_args
-    _, unravel = fu.ravel_pytree(y0)
-    z1 = unravel(z1)
     diff = (vf_prod(t1, (y0**ω + z1**ω).ω, args, control) ** ω - z1**ω).ω
-    diff, _ = fu.ravel_pytree(diff)
     return diff
 
 
@@ -49,14 +45,13 @@ class ImplicitEuler(AbstractImplicitSolver):
         del solver_state, made_jump
         control = terms.contr(t0, t1)
         pred = terms.vf_prod(t0, y0, args, control)
-        pred, unravel = fu.ravel_pytree(pred)
         jac = self.nonlinear_solver.jac(
             _implicit_relation, pred, (terms.vf_prod, t1, y0, args, control)
         )
         nonlinear_sol = self.nonlinear_solver(
             _implicit_relation, pred, (terms.vf_prod, t1, y0, args, control), jac
         )
-        z1 = unravel(nonlinear_sol.root)
+        z1 = nonlinear_sol.root
         y1 = (y0**ω + z1**ω).ω
         dense_info = dict(y0=y0, y1=y1)
         return y1, None, dense_info, None, nonlinear_sol.result
